
<?

require_once("../_php/root.php");

global $root;
require_once($root->pathToTools() . "testcase.php");
require_once($root->pathToPHP() . "question-meta.php");



if ($root->page()== "test_question-meta.php") {
  $test = new QuestionMetaTest();
  $test->runAll();
}    

class QuestionMetaTest {

  var $passed_;
  var $failed_;
  var $title_;

  var $tests_;

  function QuestionMetaTest($title = "QuestionMetaTest") {

    $testcase = new TestCase();

    $this->passed_ = $testcase->passed();
    $this->failed_ = $testcase->failed();

    $this->tests_ = Array();
    $this->title_ = $title;
  }    

  function doAll() {
    $i=-1;
    $this->tests_[$i++] = $this->test_set();
    $this->tests_[$i++] = $this->test_is();
    $this->tests_[$i++] = $this->test_load();
     $this->tests_[$i++] = $this->test_save();
     $this->tests_[$i++] = $this->test_update();
     $this->tests_[$i++] = $this->test_delete();
    return $this->tests_;
  }    

  function runAll() {
    $this->doAll();
    $testcase = new TestCase($this->title_);
    $testcase->intro($this->title_);
    foreach ($this->tests_ as $testIndex) {
      $testIndex->show();
    }      
  }   

  function debug($msg) {
    $debug_ = new Debug();
    $debug_->println("test_question-meta.php",$msg);
  }

  function debug_r($msg) {
    $debug_ = new Debug();
    $debug_->println_r("test_question-meta.php",$msg);
  }    



  function test_set() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $id = "123";   
    $question = "what is nothing?";
    $question_type = "input";
    

    $b = new QuestionMeta();
    $b->set($id,$question,$question_type);

    $testcase = new Testcase("QuestionMeta.set()");

    $descr = "set(), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "set(), checking question";
    $isSame = (strcmp($question,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "set(), checking type";
    $isSame = (strcmp($question_type,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }

  function test_is() {

    $passed = $this->passed_;
    $failed = $this->failed_;
   
    $question = "what is nothing?";
    $question_type = "this is a question about nothing";

    $testcase = new Testcase("QuestionMeta.is()");

    $descr = "Check for a null Question";
    $a = new QuestionMeta();
    $id = "";
    $ans = $a->is($id);
    $result = ($id == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Check for a 0 Question";
    $a = new QuestionMeta();
    $id = 0;
    $ans = $a->is($id);
    $result = ($id == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $a = new QuestionMeta();
    $id = $a->save($question,$question_type);
    $descr = "Cheking  newly created Question exists";
    $ans = $id;
    $result = ($a->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);   

    
    $descr = "Checking deleted Question does not exist";
    $ans = $a->delete($id);
    $result = ($a->is($id) == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }    

  function test_load() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new QuestionMeta();

    $question = "what is nothing?";
    $question_type = "input";
    
    $testcase = new Testcase("QuestionMeta.load(id)");

    $a = new QuestionMeta();
    $id = -2;
    $isLoadOkay = $a->load($id);

    $descr = "Loading Bad Question";
    $ans = $isLoadOkay;
    $result = (!$meta->is($id) && $isLoadOkay == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Creating new Question ($question,$question_type)";
    $a = new QuestionMeta();
    $id = $a->save($question,$question_type);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Loading Question ($id)";
    $b = new QuestionMeta();
    $id = $b->load($id);
    $ans = $id;
    $result = ($meta->is($id) && $id != false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id), checking question";
    $isSame = (strcmp($question,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id), checking type";
    $isSame = (strcmp($question_type,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame == true) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Removing Question";  
    $meta->delete($id);
    $ans = (! $meta->is($id)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);
   
    return $testcase;
    

  }  


  function test_save() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new QuestionMeta();

    $b = new QuestionMeta();
    $question = "how about that my friends";
    $question_type = "input";

    $question2 = "do you like ice cream";
    $question_type2 = "";


    $testcase = new Testcase("QuestionMeta.save()");

    $descr = "Creating Question ($question,$question_type)";
    $id = $b->save($question,$question_type);
    $id = $b->load($id);

    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);
 

    $descr = "Question($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id), checking question";
    $isSame = (strcmp($question,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id), checking type";
    $isSame = (strcmp($question_type,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    
    $descr= "Saving another Question (blank type)";  
    $id2 = $b->save($question2,$question_type2);
    $id2 = $b->load($id2);
    $ans = $id2;
    $result = ($meta->is($id2) && $id != $id2) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id2), checking id";
    $isSame = (strcmp($id2,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id2), checking question";
    $isSame = (strcmp($question2,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id2), checking type";
    $isSame = (strcmp("textarea",$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);


    $descr = "Removing Questions";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }  


  function test_update() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new QuestionMeta();

    $question = "what me update?";
    $question_type = "input";

    $question2 = "my update with what?";
    $question_type2 = "";
    $question_type_default = "textarea";

    $testcase = new Testcase("QuestionMeta.update()");

    $descr = "Creating Question ($question,$question_type)";
    $b = new QuestionMeta();
    $id = $b->save($question,$question_type);
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id), checking question";
    $isSame = (strcmp($question,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id), checking type";
    $isSame = (strcmp($question_type,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);  


    $descr = "Updating Question($question2,$question_type2)";
    $b->update($id,$question2,$question_type2);
    $b = new QuestionMeta();
    $id2 = $b->load($id);
    $ans = $id2;
    $result = ($meta->is($id2) && $id2 == $id) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Updated Question ($id2), checking id";
    $isSame = (strcmp($id2,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id2), checking question";
    $isSame = (strcmp($question2,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id2), checking type";
    $isSame = (strcmp($question_type_default,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);  

    $descr = "Removing Questions";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }  


  function test_delete() {


    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new QuestionMeta();

    $question = "question me?";
    $question_type = "a question about me";

    $testcase = new Testcase("QuestionMeta.delete()");

    $descr = "Creating Question ($question,$question_type)";
    $b = new QuestionMeta();
    $id = $b->save($question,$question_type);
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);


    $descr = "Deleting Question($id)";
    $b = new QuestionMeta();
    $b->delete($id);
    $ans = $id;
    $result = (!$meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;    

  }   

  
}


?>