
<?

require_once("../_php/root.php");

global $root;
require_once($root->pathToTools() . "testcase.php");
require_once($root->pathToPHP() . "question.php");

if ($root->page() == "test_question.php") {
  $test = new QuestionTest();
  $test->runAll();
}    


class QuestionTest {

  var $passed_;
  var $failed_;
  var $title_;

  var $tests_;

  function QuestionTest($title = "QuestionTest") {

    $testcase = new TestCase();

    $this->passed_ = $testcase->passed();
    $this->failed_ = $testcase->failed();
    
    $this->tests_ = Array();
    $this->title_ = $title;
  }    

  function doAll() {
    $this->tests_[0] = $this->test_init();
    $this->tests_[1] = $this->test_load();
    $this->tests_[2] = $this->test_save();
    $this->tests_[3] = $this->test_update();
    return $this->tests_;
  }    

  function runAll() {
    $this->doAll();
    $testcase = new TestCase($this->title_);
    $testcase->intro($this->title_);
    foreach ($this->tests_ as $testIndex) {
      $testIndex->show();
    }      
  }   

  function debug($msg) {
    $debug_ = new Debug();
    $debug_->println("test_question.php",$msg);
  }

  function debug_r($msg) {
    $debug_ = new Debug();
    $debug_->println_r("test_question.php",$msg);
  }    


  function test_init() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $question = "what?";
    $question_type = "input";

    $b = new Question();
    $b->init($question,$question_type);

    $testcase = new Testcase("Question.init()");

    $descr = "init($question,$question_type), checking question";
    $isSame = (strcmp($question,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "init($question,$question_type), checking type";
    $isSame = (strcmp($question_type,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }

  
  function test_load() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new QuestionMeta();

    $a = new Question();
    $question = "what?";
    $question_type = "";
    $question_type_default = "textarea";
    $testcase = new Testcase("Question.load(id)");

    
    $id = -1;
    $a = new Question();
    $isLoadOkay = $a->load($id);

    $descr = "Loading Bad Question";
    $ans = $isLoadOkay;
    $result = (!$meta->is($id) && $isLoadOkay == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Creating new Question($question,$question_type)";
    $id = $meta->save($question,$question_type);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id)";
    $b = new Question();
    $isOkay = $b->load($id);
    $ans = $isOkay;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Loading Question ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id), checking question";
    $isSame = (strcmp($question,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id), checking type";
    $isSame = (strcmp($question_type_default,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);
    
    $descr = "Removing Question";  
    $meta->delete($id);
    $ans = (! $meta->is($id)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);
   
    return $testcase;
    

  }  

  function test_save() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new QuestionMeta();

    $question = "what?";
    $question_type = "input";

    $testcase = new Testcase("Question.save()");

    $a = new Question();
    $a->init($question,$question_type);
    $id = $a->save();
    $descr = "Creating Question";
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    
    $descr= "Saving that Question again";  
    $id2 = $a->save();
    $ans = $id2;
    $result = ($meta->is($id2) && $id != $id2) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Removing Question";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }  


  function test_update() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new QuestionMeta();

    $question = "what?";
    $question_type = "input";

    $question2 = "huh?";
    $question_type2 = "";

    $question_type_default = "textarea";

    $testcase = new Testcase("Question.update()");

    $descr = "Creating Question";
    $id = $meta->save($question,$question_type);
    $b = new Question();
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id), checking question";
    $isSame = (strcmp($question,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id), checking type";
    $isSame = (strcmp($question_type,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $b->init($question2,$question_type2);

    $descr = "Updating Question";
    $b->update();
    $b = new Question();
    $id2 = $b->load($id);
    $ans = $id2;
    $result = ($meta->is($id2) && $id2 = $id) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Updated Question ($id2), checking id";
    $isSame = (strcmp($id2,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id2), checking question";
    $isSame = (strcmp($question2,$b->question_) == 0);
    $ans = $b->question_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Question($id2), checking type";
    $isSame = (strcmp($question_type_default,$b->type_) == 0);
    $ans = $b->type_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Removing Questions";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }  
}


?>