
<?

require_once("../_php/root.php");

global $root;

require_once($root->pathToTools() . "testcase.php");
require_once($root->pathToPHP() . "user-meta.php");


if ($root->page() == "test_user-meta.php") {
  $test = new UserMetaTest();
  $test->runAll();
}    

class UserMetaTest {

  var $passed_;
  var $failed_;
  var $title_;

  var $tests_;

  function UserMetaTest($title = "UserMetaTest") {

    $testcase = new TestCase();

    $this->passed_ = $testcase->passed();
    $this->failed_ = $testcase->failed();

    $this->tests_ = Array();
    $this->title_ = $title;
  }    

  function doAll() {
    $i=-1;
    $this->tests_[$i++] = $this->test_set();
    $this->tests_[$i++] = $this->test_is();
    $this->tests_[$i++] = $this->test_isLogin();
    $this->tests_[$i++] = $this->test_isEmail();    
    $this->tests_[$i++] = $this->test_load();
    $this->tests_[$i++] = $this->test_save();
    $this->tests_[$i++] = $this->test_update();
    $this->tests_[$i++] = $this->test_delete();
    return $this->tests_;
  }    

  function runAll() {
    $this->doAll();
    $testcase = new TestCase($this->title_);
    $testcase->intro($this->title_);
    foreach ($this->tests_ as $testIndex) {
      $testIndex->show();
    }      
  }   

  function debug($msg) {
    $debug_ = new Debug();
    $debug_->println("test_user-meta.php",$msg);
  }

  function debug_r($msg) {
    $debug_ = new Debug();
    $debug_->println_r("test_user-meta.php",$msg);
  }    



  function test_set() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $id = "123";   
    $email = "a@b";
    $pwd = "hello";

    $b = new UserMeta();
    $b->set($id,$email,$pwd);

    $testcase = new Testcase("UserMeta.set()");

    $descr = "set(), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "set(), checking email";
    $isSame = (strcmp($email,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "set(), checking pwd";
    $isSame = (strcmp($pwd,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }
  


  function test_is() {

    $passed = $this->passed_;
    $failed = $this->failed_;
   
    $email = "a@b";
    $pwd = "hello";

    $testcase = new Testcase("UserMeta.is()");

    $descr = "Check for a null user";
    $a = new UserMeta();
    $id = "";
    $ans = $a->is($id);
    $result = ($id == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Check for a -1 user";
    $a = new UserMeta();
    $id = -1;
    $ans = $a->is($id);
    $result = (!$a->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $a = new UserMeta();
    $id = $a->save($email,$pwd);
    $descr = "Cheking  newly created User exists";
    $ans = $a->is($id);
    $result = ($id == true) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);   

    
    $descr = "Checking deletee User does not exist";
    $ans = $a->delete($id);
    $result = ($a->is($id) == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }    

  function test_load() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $a = new User();
    $email = "a@b";
    $pwd = "hello";

    $testcase = new Testcase("UserMeta.load(id)");

    $a = new UserMeta();
    $id = -1;
    $isLoadOkay = $a->load($id);

    $descr = "Loading Bad User";
    $ans = $isLoadOkay;
    $result = (!$meta->is($id) && $isLoadOkay == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Creating new User ($email,$pwd)";
    $a = new UserMeta();
    $id = $a->save($email,$pwd);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Loading User ($id)";
    $b = new UserMeta();
    $isOkay = $b->load($id);
    $ans = $isOkay;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking email";
    $isSame = (strcmp($email,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking pwd";
    $isSame = (strcmp($pwd,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Removing users";  
    $meta->delete($id);
    $ans = (! $meta->is($id)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);
   
    return $testcase;
    

  }  


  function test_save() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $a = new UserMeta();
    $email = "save@save.com";
    $pwd = "savingpwd";

    $testcase = new Testcase("UserMeta.save()");

    $descr = "Creating User ($email,$pwd)";
    $id = $a->save($email,$pwd);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    
    $descr= "Saving that post again (should not save)";  
    $id2 = $a->save($email,$pwd);
    $ans = $id2;
    $result = (!$meta->is($id2)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Removing users";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }  


  function test_update() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $email = "a@b";
    $pwd = "hello";

    $email2 = "andrew@b.com";
    $pwd2 = "bonjour";

    $testcase = new Testcase("UserMeta.update()");

    $descr = "Creating User ($email,$pwd)";
    $b = new UserMeta();
    $id = $b->save($email,$pwd);
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking email";
    $isSame = (strcmp($email,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking pwd";
    $isSame = (strcmp($pwd,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);  


    $descr = "Updating post";
    $b->update($id,$email2,$pwd2);
    $b = new UserMeta();
    $id2 = $b->load($id);
    $ans = $id2;
    $result = ($meta->is($id2) && $id2 == $id) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Updated User ($id2), checking id";
    $isSame = (strcmp($id2,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id2), checking email";
    $isSame = (strcmp($email2,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id2), checking pwd";
    $isSame = (strcmp($pwd2,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);  

    $descr = "Removing users";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }  


  function test_delete() {


    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $email = "a@b";
    $pwd = "hello";

    $testcase = new Testcase("UserMeta.delete()");

    $descr = "Creating User ($email,$pwd)";
    $b = new UserMeta();
    $id = $b->save($email,$pwd);
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);


    $descr = "Deleting User";
    $b = new UserMeta();
    $b->delete($id);
    $ans = $id;
    $result = (!$meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;    

  }    

  function test_isLogin() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $email = "a@b";
    $pwd = "hello";
    
    $email2 = "blah@blah";
    $pwd2 = "bonjour";

    $not_an_email = "not@not.com";
    $not_a_pwd = "nothello";

    $testcase = new Testcase("UserMeta.isLogin()");

    $descr = "Creating User($email,$pwd)";
    $b = new UserMeta();
    $id = $b->save($email,$pwd);
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Creating Another User($email2,$pwd2)";
    $b = new UserMeta();
    $id2 = $b->save($email2,$pwd2);
    $b->load($id2);
    $ans = $id2;
    $result = ($meta->is($id2)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);


    $checkEmail = $not_an_email;
    $checkPwd = $not_a_pwd;
    $expected = false;
    $descr = "Checking ($checkEmail,$checkPwd))";
    $ans = $b->isLogin($checkEmail,$checkPwd);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = $email;
    $checkPwd = $not_a_pwd;
    $expected = false;
    $descr = "Checking ($checkEmail,$checkPwd))";
    $ans = $b->isLogin($checkEmail,$checkPwd);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = $email;
    $checkPwd = $pwd2;
    $expected = false;
    $descr = "Checking ($checkEmail,$checkPwd))";
    $ans = $b->isLogin($checkEmail,$checkPwd);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = $not_an_email;
    $checkPwd = $pwd;
    $expected = false;
    $descr = "Checking ($checkEmail,$checkPwd))";    
    $ans = $b->isLogin($checkEmail,$checkPwd);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = $email;
    $checkPwd = $pwd;
    $expected = true;
    $descr = "Checking ($checkEmail,$checkPwd))";    
    $ans = $b->isLogin($checkEmail,$checkPwd);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = $email2;
    $checkPwd = $pwd2;
    $expected = true;
    $descr = "Checking ($checkEmail,$checkPwd))";    
    $ans = $b->isLogin($checkEmail,$checkPwd);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Deleting Users";
    $b = new UserMeta();
    $b->delete($id);
    $b->delete($id2);    
    $ans = $id;
    $result = (!$meta->is($id) && !$meta->is($id2)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }

  function test_isEmail() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $email = "a@b";
    $pwd = "hello";

    $not_an_email = "blah@b.blah";
 
    $testcase = new Testcase("UserMeta.isEmail()");


    $b = new UserMeta();
    $id = $b->save($email,$pwd);
    $b->load($id);

    $descr = "Creating User($email,$pwd)";
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = null;
    $expected = false;
    $descr = "checking email($checkEmail)";
    $ans = $b->isEmail($checkEmail);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = "";
    $expected = false;
    $descr = "checking email($checkEmail)";
    $ans = $b->isEmail($checkEmail);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = $not_an_email;
    $expected = false;
    $descr = "checkign email($checkEmail)";
    $ans = $b->isEmail($checkEmail);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $checkEmail = $email;
    $expected = true;
    $descr = "checkign email($checkEmail)";
    $ans = $b->isEmail($checkEmail);
    $result = ($ans == $expected) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Deleting User";
    $b = new UserMeta();
    $b->delete($id);
    $ans = $id;
    $result = (!$meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);    

    return $testcase;

  }    

  
}


?>