
<?

require_once("../_php/root.php");

global $root;

require_once($root->pathToTools() . "testcase.php");
require_once($root->pathToPHP() . "user.php");


if ($root->page() == "test_user.php") {
  $test = new UserTest();
  $test->runAll();
}    


class UserTest {

  var $passed_;
  var $failed_;
  var $title_;

  var $tests_;

  function UserTest($title = "UserTest") {

    $testcase = new TestCase();

    $this->passed_ = $testcase->passed();
    $this->failed_ = $testcase->failed();

    $this->tests_ = Array();
    $this->title_ = $title;
  }    

  function doAll() {
    $i = 0;
    $this->tests_[$i++] = $this->test_init();
    $this->tests_[$i++] = $this->test_load();
    $this->tests_[$i++] = $this->test_save();
    $this->tests_[$i++] = $this->test_update();
    $this->tests_[$i++] = $this->test_delete();
    return $this->tests_;
  }    

  function runAll() {
    $this->doAll();
    $testcase = new TestCase($this->title_);
    $testcase->intro($this->title_);
    foreach ($this->tests_ as $testIndex) {
      $testIndex->show();
    }      
  }   

  function debug($msg) {
    $debug_ = new Debug();
    $debug_->println("test_user.php",$msg);
  }

  function debug_r($msg) {
    $debug_ = new Debug();
    $debug_->println_r("test_user.php",$msg);
  }    


  function test_init() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $email = "blah@blah";
    $pwd = "hello";

    $b = new User();
    $b->init($email,$pwd);

    $testcase = new Testcase("User.init()");

    $descr = "init($email,$pwd), checking email";
    $isSame = (strcmp($email,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "init($email,$pwd), checking pwd";
    $isSame = (strcmp($pwd,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }

  
  function test_load() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $a = new User();
    $email = "blah@blah";
    $pwd = "hello";

    $testcase = new Testcase("User.load(id)");

    
    $id = -1;
    $a = new User();
    $isLoadOkay = $a->load($id);

    $descr = "Loading Bad User";
    $ans = $isLoadOkay;
    $result = (!$meta->is($id) && $isLoadOkay == false) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Creating new User($email,$pwd)";
    $id = $meta->save($email,$pwd);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id)";
    $b = new User();
    $isOkay = $b->load($id);
    $ans = $isOkay;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Loading User ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Loading User ($id), checking email";
    $isSame = (strcmp($email,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Loading User ($id), checking pwd";
    $isSame = (strcmp($pwd,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);
    
    $descr = "Removing User";  
    $meta->delete($id);
    $ans = (! $meta->is($id)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);
   
    return $testcase;
    

  }  

  function test_save() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $email = "blah@blah";
    $pwd = "hello";

    $testcase = new Testcase("User.save()");

    $a = new User();
    $a->init($email,$pwd);
    $id = $a->save();
    $descr = "Creating User";
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    
    $descr= "Saving that User again (results is error)";  
    $id2 = $a->save();
    $ans = $id2;
    $result = (!$meta->is($id2)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Removing User";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }  


  function test_update() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $email = "blah@blah";
    $pwd = "hello";

    $email2 = "james@noway.org";
    $pwd2 = "bonjour";

    $testcase = new Testcase("User.update()");

    $descr = "Creating User";
    $id = $meta->save($email,$pwd);
    $b = new User();
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking id";
    $isSame = (strcmp($id,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking email";
    $isSame = (strcmp($email,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id), checking pwd";
    $isSame = (strcmp($pwd,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $b->init($email2,$pwd2);

    $descr = "Updating post";
    $b->update();
    $b = new User();
    $id2 = $b->load($id);
    $ans = $id2;
    $result = ($meta->is($id2) && $id2 = $id) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Updated User ($id2), checking id";
    $isSame = (strcmp($id2,$b->id_) == 0);
    $ans = $b->id_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id2), checking email";
    $isSame = (strcmp($email2,$b->email_) == 0);
    $ans = $b->email_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "User ($id2), checking pwd";
    $isSame = (strcmp($pwd2,$b->pwd_) == 0);
    $ans = $b->pwd_;
    $result = ($isSame) ? $passed : $failed;
    $testcase->add($descr,$ans,$result); 

    $descr = "Removing users";  
    $meta->delete($id);
    $meta->delete($id2);
    $ans = (! $meta->is($id) && ! $meta->is($id2)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }

  function test_delete() {

    $passed = $this->passed_;
    $failed = $this->failed_;

    $meta = new UserMeta();

    $email = "blah@blah";
    $pwd = "hello";

    $testcase = new Testcase("User.update()");

    $descr = "Creating User";
    $id = $meta->save($email,$pwd);
    $b = new User();
    $b->load($id);
    $ans = $id;
    $result = ($meta->is($id)) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    $descr = "Deleting user";  
    $meta->delete($id);
    $ans = (! $meta->is($id)) ;
    $result = ($ans) ? $passed : $failed;
    $testcase->add($descr,$ans,$result);

    return $testcase;

  }    
  
}


?>